@@ -1,6 +1,6 @@
 package IPC::Simple;
 # ABSTRACT: simple, non-blocking IPC
-$IPC::Simple::VERSION = '0.05';
+$IPC::Simple::VERSION = '0.06';
 
 use strict;
 use warnings;
@@ -65,6 +65,7 @@ sub new {
     exit_status => undef,
     exit_code   => undef,
     messages    => undef,
+    kill_timer  => undef,
   }, $class;
 }
 
@@ -154,6 +155,7 @@ sub launch {
 
   $self->{exit_status} = undef;
   $self->{exit_code}   = undef;
+  $self->{kill_timer}  = undef;
   $self->{pid}         = $pid;
   $self->{handle_err}  = $self->_build_input_handle($err, IPC_STDERR);
   $self->{handle_out}  = $self->_build_input_handle($out, IPC_STDOUT);
@@ -207,6 +209,7 @@ sub _on_error {
 
 sub _on_exit {
   my ($self, $status) = @_;
+  undef $self->{kill_timer};
   $self->run_state(STATE_READY);
   $self->{exit_status} = $status || 0;
   $self->{exit_code} = $self->{exit_status} >> 8;
@@ -217,8 +220,10 @@ sub _on_exit {
     $self->{exit_code},
   );
 
-  $self->{messages}->shutdown
-    if $self->{messages}; # won't be set if launch failed early enough
+  # May not be set yet if launch fails early enough
+  if ($self->{messages}) {
+    $self->{messages}->shutdown;
+  }
 }
 
 sub _on_read {
@@ -253,20 +258,42 @@ sub _queue_message {
   }
 }
 
+#-------------------------------------------------------------------------------
+# Send a signal to the process
+#-------------------------------------------------------------------------------
+sub signal {
+  my ($self, $signal) = @_;
+  if ($self->{pid}) {
+    $self->debug('sending %s to pid %d', $signal, $self->{pid});
+    kill $signal, $self->{pid};
+  }
+}
+
 #-------------------------------------------------------------------------------
 # Stopping the process and waiting on it to complete
 #-------------------------------------------------------------------------------
 sub terminate {
   my $self = shift;
+  my $timeout = shift;
+
   if ($self->is_running) {
+    $self->signal('TERM');
     $self->run_state(STATE_STOPPING);
-    $self->debug('sending TERM to pid %d', $self->{pid});
-    kill 'TERM', $self->{pid};
 
     $self->{handle_in}->push_shutdown;
     $self->{handle_out}->push_shutdown;
     $self->{handle_err}->push_shutdown;
 
+    if (defined $timeout) {
+      $self->{kill_timer} = AnyEvent->timer(
+        after => $timeout,
+        cb => sub{
+          $self->signal('KILL');
+          undef $self->{kill_timer};
+        },
+      );
+    }
+
     if ($self->{term_cb}) {
       $self->{term_cb}->($self);
     }
@@ -333,7 +360,7 @@ IPC::Simple - simple, non-blocking IPC
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -489,8 +516,16 @@ the process.
 
 =head2 terminate
 
-Sends the child process a `SIGTERM`. Returns immediately. Use L</join> to wait
-for the process to finish.
+Sends the child process a C<SIGTERM>. Returns immediately. Use L</join> to wait
+for the process to finish. An optional timeout may be specified in fractional
+seconds, after which the child process is issued a C<SIGKILL>.
+
+=head2 signal
+
+Sends a signal to the child process. Accepts a single argument, the signal type
+to send.
+
+  $proc->signal('TERM');
 
 =head2 join
 
